@@ -29,7 +29,7 @@ modname = "common"
 subpackage_of = "logilab"
 subpackage_master = True
 
-numversion = (1, 9, 4)
+numversion = (1, 9, 5)
 version = ".".join([str(num) for num in numversion])
 
 license = "LGPL"  # 2.1 or later
@@ -43,21 +43,21 @@ author_email = "contact@logilab.fr"
 scripts = [join("bin", "logilab-pytest")]
 include_dirs = [join("test", "data")]
 
-install_requires = [
-    "setuptools",
-    "mypy-extensions",
-    "typing_extensions",
-]
+__depends__ = {
+    "setuptools": None,
+    "mypy-extensions": None,
+    "typing_extensions": None,
+}
 tests_require = [
     "pytz",
     "egenix-mx-base",
 ]
 
 if os.name == "nt":
-    install_requires.append("colorama")
+    __depends__["colorama"] = None
 
 if sys.version_info < (3, 8):
-    install_requires.append("importlib_metadata")
+    __depends__["importlib_metadata"] = None
 
 classifiers = [
     "Topic :: Utilities",
