@@ -509,7 +509,7 @@ def attribute_renamed(old_name: str, new_name: str, version: Optional[str] = Non
                     "old_name": old_name,
                     "new_name": new_name,
                     "version": version,
-                    "package": _get_package_name(self.__class__),
+                    "package": _get_package_name(klass),
                 },
                 stacklevel=3,
                 version=version,
@@ -526,7 +526,7 @@ def attribute_renamed(old_name: str, new_name: str, version: Optional[str] = Non
                     "old_name": old_name,
                     "new_name": new_name,
                     "version": version,
-                    "package": _get_package_name(self.__class__),
+                    "package": _get_package_name(klass),
                 },
                 stacklevel=3,
                 version=version,
@@ -543,7 +543,7 @@ def attribute_renamed(old_name: str, new_name: str, version: Optional[str] = Non
                     "old_name": old_name,
                     "new_name": new_name,
                     "version": version,
-                    "package": _get_package_name(self.__class__),
+                    "package": _get_package_name(klass),
                 },
                 stacklevel=3,
                 version=version,
